searchData={"content_type":"text/markdown","items":[{"doc":"`Req` plugin for [Trino](https://trino.io/).\n\nReqTrino makes it easy to make Trino queries. Query results are decoded into the `ReqTrino.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"ReqTrino.html","title":"ReqTrino","type":"module"},{"doc":"Attaches to Req request.","ref":"ReqTrino.html#attach/2","title":"ReqTrino.attach/2","type":"function"},{"doc":"* `:host` - Required. The Trino host.\n\n  * `:user` - Required. The Trino user.\n\n  * `:password` - Required. The Trino password.\n\n  * `:catalog` - Required. The default catalog to connect.\n\n  * `:trino` - Required. The query to execute. It can be a plain sql string or\n    a `{query, params}` tuple, where `query` can contain `?` placeholders and `params`\n    is a list of corresponding values.\n\nConditional fields must always be defined, and can be one of the fields or both.\n\nIf you want to set any of these options when attaching the plugin, pass them as the second argument.","ref":"ReqTrino.html#attach/2-request-options","title":"Request Options - ReqTrino.attach/2","type":"function"},{"doc":"With plain query string:\n\n    iex> opts = [\n    ...>   user: System.fetch_env!(\"TRINO_USER\"),\n    ...>   password: System.fetch_env!(\"TRINO_PASSWORD\"),\n    ...>   catalog: System.fetch_env!(\"TRINO_CATALOG\"),\n    ...>   host: System.fetch_env!(\"TRINO_HOST\")\n    ...> ]\n    iex> query = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n    iex> req = Req.new() |> ReqTrino.attach(opts)\n    iex> Req.post!(req, trino: query).body\n    %ReqTrino.Result{\n      columns: [\"id\", \"type\", \"tags\", \"members\", \"timestamp\", \"visible\"],\n      rows: [\n        [470454, \"relation\",\n         \"{ref=17229A, site=geodesic, name=Mérignac A, source=©IGN 2010 dans le cadre de la cartographie réglementaire, type=site, url=http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A, network=NTF-5}\",\n         \"[{type=node, ref=670007839, role=}, {type=node, ref=670007840, role=}]\",\n         ~N[2017-01-21 12:51:34.000], true]\n      ],\n      statement_name: nil\n    }\n\nWith parameterized query:\n\n    iex> opts = [\n    ...>   user: System.fetch_env!(\"TRINO_USER\"),\n    ...>   password: System.fetch_env!(\"TRINO_PASSWORD\"),\n    ...>   catalog: System.fetch_env!(\"TRINO_CATALOG\"),\n    ...>   host: System.fetch_env!(\"TRINO_HOST\")\n    ...> ]\n    iex> query = \"SELECT id, type FROM planet WHERE id = ? and type = ?\"\n    iex> req = Req.new() |> ReqTrino.attach(opts)\n    iex> Req.post!(req, trino: {query, [239_970_142, \"node\"]}).body\n    %ReqTrino.Result{\n      columns: [\"id\", \"type\"],\n      rows: [[239_970_142, \"node\"]],\n      statement_name: \"query_C71EF77B8B7B92D9846C6D7E70136448\"\n    }","ref":"ReqTrino.html#attach/2-examples","title":"Examples - ReqTrino.attach/2","type":"function"},{"doc":"","ref":"ReqTrino.html#build_req_params/2","title":"ReqTrino.build_req_params/2","type":"function"},{"doc":"","ref":"ReqTrino.html#decode_body/2","title":"ReqTrino.decode_body/2","type":"function"},{"doc":"Result struct returned from any successful query.\n\nIts fields are:\n\n  * `columns` - The column names;\n  * `rows` - The result set. A list of lists, each inner list corresponding to a\n    row, each element in the inner list corresponds to a column;\n  * `statement_name` - The statement name from executed query;\n  * `query_execution_id` - The id from executed query;","ref":"ReqTrino.Result.html","title":"ReqTrino.Result","type":"module"},{"doc":"","ref":"ReqTrino.Result.html#t:t/0","title":"ReqTrino.Result.t/0","type":"type"},{"doc":"# ReqTrino\n\n[Req](https://github.com/wojtekmach/req) plugin for [Trino](https://trino.io/).\n\nReqTrino makes it easy to make Trino queries. Query results are decoded into the `ReqTrino.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.\n\n*This is a project that was created based on the code from ReqAthena.*\n\nWe only supports Basic Authentication!","ref":"readme.html","title":"ReqTrino","type":"extras"},{"doc":"```elixir\nMix.install([\n  {:req, \"~> 0.3.5\"},\n  {:req_trino, \"~> 0.1.0\"}\n])\n\nopts = [\n  host: my.trino.host,\n  user: trino_user,\n  password: *******,\n  catalog: \"raw\"\n]\n\nreq = Req.new() |> ReqTrino.attach(opts)\n\nquery = \\\"\"\"\nSHOW TABLES FROM system.runtime;\n\\\"\"\"\n\nReq.post!(req, trino: query).body\n#=>\n# %ReqTrino.Result{\n#   columns: [],\n#   query_id: \"a034610b-daaf-4c8d-aa61-d1a706231062\",\n#   rows: [],\n#   statement_name: nil\n# }\n\n# With plain string query\nquery = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n\nReq.post!(req, trino: query).body\n#=>\n# %ReqTrino.Result{\n#   columns: [\"id\", \"type\", \"tags\", \"members\", \"timestamp\", \"visible\"],\n#   query_id: \"c594d5df-9879-4bf7-8796-780e0b87a673\",\n#   rows: [\n#     [470454, \"relation\",\n#      \"{ref=17229A, site=geodesic, name=Mérignac A, source=©IGN 2010 dans le cadre de la cartographie réglementaire, type=site, url=http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A, network=NTF-5}\",\n#      \"[{type=node, ref=670007839, role=}, {type=node, ref=670007840, role=}]\",\n#      ~N[2017-01-21 12:51:34.000], true]\n#   ],\n#   statement_name: nil\n# }\n```","ref":"readme.html#usage","title":"Usage - ReqTrino","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}